#
# spec file for package chirp
#
# Copyright (c) 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
# Copyright (c) 2025 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pythons python3
Name:           chirp
Version:        20250704
Release:        lp160.68.1
Summary:        Tool for programming amateur radio sets
License:        GPL-3.0-only
Group:          Productivity/Hamradio/Other
URL:            https://chirpmyradio.com/projects/chirp/
Source:         %{name}-%{version}.tar.gz
Patch0:         chirp-no-phone-home.patch
Patch1:         quilt-disable-clickwrap-license.patch
BuildRequires:  %{python_module pyserial}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wxPython}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  update-desktop-files
Requires:       python3-pyserial
Requires:       python3-requests
Requires:       python3-suds
Requires:       python3-wxPython
Requires:       python3-yattag
%if 0%{?suse_version} > 1600
Requires:       python3-lark
%else
Requires:       python3-lark-parser
%endif
BuildArch:      noarch

%description
CHIRP is a free, open-source tool for programming your amateur radio. It
supports a large number of manufacturers and models, as well as provides
a way to interface with multiple data sources and formats.

%prep
%autosetup -p1
# remove shebang from lib files
sed -i '1{/^#!\//d}' %{name}/cli/experttune.py
sed -i '1{/^#!\//d}' %{name}/cli/main.py

%build
# building from git snapshot - build translations
pushd chirp/locale
%make_build
popd
%python_build

%install
%python_install
rm -rf %{buildroot}%{_datadir}/doc/%{name}
%find_lang CHIRP
%fdupes %{buildroot}%{_prefix}
%suse_update_desktop_file -c chirp CHIRP "Amateur Radio Rig Programming Tool" chirp chirp "Network;HamRadio"
install -Dpm 0644 chirp/share/chirp.svg %{buildroot}/%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
install -Dpm 0644 chirp/share/chirp.png %{buildroot}/%{_datadir}/pixmaps/%{name}.png

%files -f CHIRP.lang
%license COPYING
%{_bindir}/*
%{_datadir}/applications/%{name}.desktop
%{python_sitelib}/*.egg-info
%{python_sitelib}/%{name}
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_datadir}/pixmaps/%{name}.png

%changelog
* Sat Jul  5 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 20250704:
  * tk760g: Fix deprecated current value settings
  * tk760g: Add Off-hook-decode setting
  * Unify modern kenwood commercial step handling
  * tk3140: Fix tuning step selection
* Wed Jun 25 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 20250620:
  * tk272g: Allow full-range entry on both models
  * Add Radioddity GM-30
  * h777: Convert to using ignore bits on BCD tones
  * Add ignore_bits to bcdDataType
* Fri Jun  6 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 20250606:
  * Add MaxTalker MT-5RM
  * New Model Retevis RA25, Radioddity DB-20, AnyTone 779UV
* Fri May 30 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 20250530:
  * rt470: Add v1.27A firmware version
  * Fix TD-H8 SHORT_KEY_TOP not saving
  * Inverted FM Allow Receive setting
  * Inverted FM VFO/CH setting
  * Update french translations
* Fri May 16 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 20250516:
  * Correct P15UV model alias to UV-13Pro
  * Remove a bunch of overly verbose yaesu_clone logging
  * Fix hardware flow flag for TH-K2,TM-271/281, etc
  * Updated Italian Translation
  * Updated Spanish Translation
* Fri May  9 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 20250509:
  * Modify TIDRADIO TD-H8 and TD-H3 Driver for consistency and
    New Settings
  * tdh3: Fix invalid brightness setting in test image
  * Add a link in the about box to open online documentation
  * update translations
* Sat May  3 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 20250502:
  * Raise a specific error for fixed banks with link
  * Unify handling of RadioSpecificError in common
* Sat Apr 26 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 20250425:
  * th350: Fix FM preset failure in settings on US version
  * dr735: Fix handling out-of-range extra settings
  * Update bg_BG.po
  * New settings for Wouxun KG-805g
* Fri Apr  4 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 20250404:
  * TH9000: Add programmable buttons to settings.
  * tk280: Fix choosing highest applicable tuning step
  * Change lower bound valid_bands acceptance test
  * Simplify required_step() to honor the allow list
  * Fix two unused globals for new flake8
  * ic9700: Decode cross tone modes
  * KG805G fix: Duplex field calculated wrong
  * tk8180: Fix choosing max step
  * tk8180: Fix 12.5kHz-required step frequencies
* Fri Mar 28 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 20250328:
  * Add driver for Wouxun KG-805g
  * Updated Italian, Spanish Translation
  * Initial support of QYT KT-5000.
  * kg816/818: Fix query string processing
  * add UV21ProV2 and UV21ProGPS
  * Disable immutable mem.extra in expanded memory editor
  * update upper frequency limit that is displayed in validation
    error message
* Fri Mar 21 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 20250321:
  * Fix radio prompt disable flag checking
  * Fix scrolling in "info" tab
  * fix "cloning from" to cloning to" message
  * IC-T10: Adding Icom IC-T10 driver
  * Add Baofeng K61 model alias
  * Compress F8HP Pro and BFK6 memory maps
  * baofeng_uv17Pro.py: add Baofeng_K6
  * baofeng_uv17Pro.py: address 'DeprecationWarning' issues
  * baofeng_uv17Pro.py: address 'FutureWarning' issues
  * RT-470X: Adds NAM mode
  * mml_jc8810: Enables Scramble and Encryption feature
  * Fix Baofeng K5-Plus marked as unconfirmed for py3
  * Fix FM-converted D-STAR repeaterbook entries
  * baofeng_uv17Pro.py: correct DTMF mapping
  * Add roger beep list for TD-H3
  * Add Support for Wouxun KG-935H
  * Fix GMRS negative offset in band plan
* Sun Mar 16 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 20250314:
  * tdh8: Eliminate duplex requirement on mems 31-52
  * Remove TH-350 from the unsupported list
  * Fix TSV paste bringing in a ghost memory
  * Add "copy portable" to memedit right-click menu
* Fri Mar  7 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 20250307:
  * th_uv88: Add Dual Wait settings for RA89,P2,etc
  * Fix Cut/Paste active in right-click for query source
  * Un-flatten int settings in browser view
  * Updated Italian Translation
* Sat Mar  1 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 20250301:
  * Fix repeaterbook query loading
* Fri Feb 28 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 20250228:
  * Updated Spanish, Romanian translation
  * Update MURS stock config with power levels
  * Add TX-frequency workflow option for memory editor
  * tk8180: Use tk280's subdev generator metaclass
  * tk280: Refactor subdev metaclass generator
  * Add TH-888S model alias
  * tk8180: Fix Zone Dn, LCD Bright button functions
* Fri Feb 21 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 20250221:
  * Try to parse TSV lines from a paste
  * new sources mapy73.pl
  * Fix getting grid cursor on wx 4.0.x
  * uv17pro: Avoid decode crash on garbage names
  * Fix insert row missing undo action coverage
* Fri Feb 14 2025 andreas.stieger@gmx.de
- Update to version 20250214:
  * Make UI avoid re-deleting memories for cut/paste
  * tk481: Fix re-deleting memory corrupting data structures
  * tk481: Properly strip non-space padding
  * rh5rv2: Convert to py3
  * icf.py: Replace numeric literals where names have already been defined
  * chore: remove last use of future
  * Updated Italian Translation
  * Add Baofeng P15UV alias
  * Prevent reporting to closed bugs
  * Add undo/redo support for memory editor
  * Avoid showing temporary and hidden stock files
  * Updated Italian Translation
* Thu Feb 13 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Fix Leap installation: python3-lark vs. python3-lark-parser
* Fri Feb  7 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 20250207:
  * tk280: Fix scan/skip setting
  * tk280: Fix DAT file detection when extension is capitalized
  * tk690: Expose proper PLL steps for 690,790,890
  * ft450: Mark as nostep_tuning because 1Hz tuning
  * icx90: Fix missing tuning steps for TV memories
  * Add "include cached" toggle for RepeaterBook query
  * Add accelerator key for RepeaterBook query
  * UI improvements and translation updates
  * icf520: Add tuning steps
  * icf520: Clarify display inhibit and tx inhibit
  * anytone: Add PTTID setting
  * fix retevis rb626 support
  * Added Icom IC-7410
* Sat Feb  1 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 20250131:
  * Add support for Icom IC-F621, Kenwood TK-981, TK-481
  * Updated Spanish and Italian translations
  * Bug fixes
* Sat Jan 25 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 20250124:
  * Add TK-880 and TK-780 support
  * TK690: Add test frequencies to settings, fix power level
    handling, and fix k3 band limits
  * tk280: Add mobile-only key definitions
  * kguv920p: Fix initializing new memories
  * tk8180: Support key assignments
  * tk8180: Add battery save, warning, pttid settings
  * tk8180: Fix loading settings with multiple zones
  * tk280: Add OST backup and direct settings
  * Minor UI tweaks and translation updates
* Sat Jan 18 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 20250117:
  * Multiple modules: Fix tuning step encoding
  * tk280: Fix supporting duplex=split and other improvements
  * UI: Improve keyboard navigation from setting group to editor
  * Add Kenwood TK-280,380 support
  * add Retevis H777H PMR version, Radtel H777H FRS version
  * uv17pro: Fix exposing static banks on some models
* Sun Jan 12 2025 Andreas Stieger <andreas.stieger@gmx.de>
- require Python lark module
* Sat Jan 11 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 20250110:
  * Improve keyboard navigation and editing
  * Add Baofeng BFT20D radio
  * rt21: Fix DTCS decoding when stored in hex
  * tdh3: Fix incorrect ponmsg and step list values
  * Update UV-5GPlus model alias
  * Added support for Kenwood TS-790E
  * kenwood_live: Refresh memory after setting
* Wed Jan  1 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 20241226:
  * Add basic support for Baofeng W31D and BF-T20D
  * Add driver for Kenwood TK690, TK790, and TK890.
  * Translations updates, UI fixes
  * Add legal power limits for US FRS and GMRS, replacing chirp's
    auto-populated 50W on all channels
  * Add MaxTalker P15
  * Add Subpport for BF-F8HP-PRO firmware v0.33
* Sat Dec  7 2024 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 20241206:
  * radtel_rt490: Fix deprecations
  * radtel_rt490: Add language toggle
  * rt490: Fix channel names in chinese characters
  * Add TYT TH-350US version
  * translations updates
  * Initial support for Radtel RT-620 (GPS) radio, based on UV17
  * UI fixes
  * ft70: Some bank assignment fixes
  * Initial ICOM IC-M710 driver
  * icf: Allow drivers to skip clone result
  * Add Radtel RT-470X Plus BT signature
  * query sources: add przemienniki.eu
  * icv80: Fix txinhibit as duplex=off
  * ft70: Fix tuning steps 5.0 and 6.25
  * Add US GMRS bandplan defaults
  * bandplan: Allow offset defaults without duplex
  * Backup radio image before each upload
  * Avoid force-wrapping long locale lines
  * tdh8: Update power definitions for TD-H3
  * tdh8: Convert all OFF/ON selections to checkboxes
  * tdh8: Add settings from 240416 TD-H3 firmware
  * Make baofeng_common radios suggest K1 help
  * id31/51: Fix TSQL/DTCS "error" on CS-31
  * id31/51: Fix 6.25kHz offsets values
  * id51: Fix loading ICF files
- disable clickwrap license dialog
  quilt-disable-clickwrap-license.patch
* Sun Nov  3 2024 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 20241101:
  * dr735t: Add bell and favorite to extra settings and set their default values
  * uv17pro: Expose static bank model for clarity
  * Add static bank/model which refuses any change
  * Add Baofeng UV-17R alias
  * Add airband to all bandplans with default to AM
  * Avoid restoring window to a negative coordinate
  * Add 10-level squelch to BF 5RM and BF K5-Plus radios
  * Add alias for TIDRADIO TD-V2
  * Add UV-17M model alias
  * Add Yaesu VX-177 support
  * tdh3: Fix high VHF and UHF RX bands for HAM variant
  * rt98: Enable V101 version for UHF variant
  * rt21: Add BCL clarification tooltip
  * Add Baofeng UV-5RH
  * rt98: Add missing test image
  * rt98: Add some tip docs for squelch settings
  * anytone: Attempt flush input before ident
  * Talkpod A36plus: add support for firmware v1.26
  * New device: TYT TH-UV98
  * btech.py: QYT KT8900D add new mcu version
  * btech.py: QYT KT8900 add new mcu version
  * btech.py: Radioddity QB25 add new mcu version
  * rt470x: Support 18MHz-1G per new firmware changes
  * bff8hppro: Fix to include mid power level
  * anytone: Fix missing DTCS->DTCS cross mode
  * rt98: Add support for firmware V101
  * icw32: Add 12.5kHz tuning step
  * Add TYT TH-7900 model to alias map
  * uvk5: Add OSFW-bd90ca3 as found in the wild
  * btech: Handle failure to decode FM presets
  * Add Baofeng BF-F8HP-PRO
  * uv17pro: Fix AM emulation handling
  * Add UV17R-Plus
  * Add user-contributed US Aviation stock config
  * rt470x: Enable proper AM mode handling
  * ft8100: Update locale files
  * ft8100: Changed upload and download prompt
  * rt622: Add new identification string
  * ga510v2: Limit name to 8 chars per OEM
  * Add Baofeng AR-5RM to model alias map
  * rt490: Hand-fix a complex settings list index
  * rt470: Fix out-of-range setting handling
  * Add MaxTalker TK-6 and MT-8S aliases
  * Add Retevis RB626
  * ga510: Add airband for SenhaiX 8800
  * rt22: Fix tones not being enabled
  * rt21: Fix "voice annunciation" typo
  * senhaix8800: Fix setting tx inhibit on simplex
  * ga510: Fix ANI group code out of range
  * ft857, ft4, anytone778uv: Fix incorrect DTCS handling
  * UI fixes and translations updates
* Wed Aug 28 2024 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 20240827:
  * Fix kenwood V7A and derivatives flow control
  * uvk5: Bless 3.00.x firmware
  * uvk5: Fix read-only download from any firmware
  * kenwood_d7: Fix missing valid_bands
  * tdh8, tdh3: Further revise the AM handling
  * px777: Support newer radio revisions
  * ic9700: Add satellite memories
  * Add Icom IC-9700 support
  * Fix memedit extra expansion with live radios
* Fri Aug 23 2024 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 20240820:
  * Update locale for recent changes
  * uvk5: Bless 5.00.x firmware versions
  * uvk5: Add a restricted version for unsupported firmwares
  * Mark extra columns immutable if mem.extra is
  * Fix setting extra comment if immutable
  * ft70: Remove incorrect lowercase support
  * ft4: Make a few strings translatable.
  * uvk5 driver to reference chirp_common ctcss/dtcs codes
  * Add welcome screen images for Bulgarian
  * RT490: Add supported charset
* Thu Aug 15 2024 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 20240813:
  * ga510v2: Fix power level handling
  * tdh3: Fix VFO power level settings
  * uv17Pro: Note the A/B selection byte
  * Add Radioddity DB50 model alias
  * btech: Handle out-of-range reset time setting
  * thd8: Fix ham model RX-bands
  * Add padding support to icf.warp_byte_size
* Sat Aug 10 2024 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 20240806:
  * ksun_m6: Fix initialization of new memories
  * retevis_rt21.py: Add Retevis RB89
  * retevis_rt21.py: fix incorrect DTCS mask
  * Add AppStream metadata
  * Add Bulgarian translation
  * Fix URL in README.md
  * Fix linux bugreport menu item failure
  * Update Italian Translation
  * Updated Spanish Translation
  * Add ability to report new bugs from within CHIRP
- package now build from git / source service
* Mon Jun 17 2024 Andreas Stieger <andreas.stieger@gmx.de>
- drop chirp-backport-to-python36.patch, no longer needed
* Mon Jun 17 2024 Dominik Heidler <dheidler@suse.de>
- Remove shebang from lib files
- Rebase chirp-no-phone-home.patch
* Mon Jun 17 2024 Dominik Heidler <dheidler@suse.de>
- Remove dependency on python3-future
* Sat Jun 15 2024 Andreas Stieger <andreas.stieger@gmx.de>
- update to 20240614:
  * New and updated supported radio models
  * Fix import issues from multiple sources
  * Bug fixes
* Fri Mar 29 2024 Andreas Stieger <andreas.stieger@gmx.de>
- Update to 20240322:
  * Many new and updated supported radio models
* Thu Dec 21 2023 Andreas Stieger <andreas.stieger@gmx.de>
- Update to 20231220:
  * Add Quansheng UV-K6 as alias to Quansheng UV-K5
  * Add Retevis RA79
  * Add FT-450 support to FT450D driver
* Fri Oct 20 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 20231016
* Mon Aug 21 2023 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 20230818:
  * add Abbree AR-730, AR-F5, Baofeng W31E, Radtel RT-470X
  * fix RB15/RB615: fix tone squelch issue
  * FT818: Add PMS as possible scan mode
  * Fix import DVMemory to D74
  * Fix leaving live radio serial port open
* Sun Jul 23 2023 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 20230722:
  * Created stock config file for SP / Poland (SP)
  * UI fixes and bug fixes, translation updates
  * Add subclasses for BF1901 and BF1904
  * Add Baofeng BF-1902 and BF-1903 to alias map
  * Fix th7800
  * UV-K5: add UV-K5(8) as an alias, add option to disable tx on a
    channel
  * Baofeng UV-6R: fix broken upload/download
  * tk3140: Add battery save settings
  * uv5r: Multiple changes
  * Retevis RT-470: Expand Supported Frequency Ranges
  * Model Alias Map Update: RB27B, RB27V and RB627B can be
    programed with the RB27 model selection.
* Sun Jul  2 2023 Andreas Stieger <Andreas.Stieger@gmx.de>
- Update to version 20230701:
  * Support full band TX/RX for Retevis RB75, H777s, RT24, RB27
  * Allow overriding stock_configs directory
  * Clean up legacy stock config files
  * Retevis RB627B/RB27B/RB27V: Update Time-Out-Timer list
  * Overhaul of Kenwood D7 Driver
  * UI fixes and bug fixes
* Sun Jun 25 2023 Andreas Stieger <Andreas.Stieger@gmx.de>
- Update to version 20230622:
  * Implement simple import function
  * Make radio browser read-only in frozen builds
  * Small UI dialog improvements
* Sat Jun 24 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Rebase patch chirp-backport-to-python36.patch to current snapshot
* Tue Jun 20 2023 Andreas Stieger <Andreas.Stieger@gmx.de>
- Update to version 20230619:
  * Improve IC9x driver
  * Allow interacting with sub-device radios
  * Allow interacting with live drivers
  * Bump new version warning interval
  * Add PR check for added driver with no added image
  * Make fast-driver fall back to all drivers
  * Make fast-driver look for dependencies
  * RT29: Add Extra DTCS Codes
  * Fix broken FTM-7250 driver for recent FTx changes
  * Disable HARDWARE_FLOW for Kenwood TH-F6
* Mon Jun 12 2023 Andreas Stieger <andreas.stieger@gmx.de>
- Update to 20230611:
  * Update Spanish Translation
  * Fix setting extras (mem.extra) on non-english translations
  * Remove extraneous debug from uv5r driver
* Sat Jun 10 2023 Andreas Stieger <Andreas.Stieger@gmx.de>
- Update to 20230608:
  * RT-470: support firmware update v1.22
  * Fix FT2800 driver
  * Add support for Hiroyasu HI-8811
  * Add support for changing knob controls on tk3140
  * Add support for Anysecu UV-A37
* Fri Jun  2 2023 Andreas Stieger <Andreas.Stieger@gmx.de>
- Update to 20230602:
  * Updates to FT-450 driver
  * Fix config issues with %% in filenames
  * Fix frequency range for IC-7300
  * DV Mode fixes
  * Fix setting extra fields on IC-V80
* Wed May 17 2023 Andreas Stieger <andreas.stieger@gmx.de>
- Update to 20230515:
  * Mark Alinco DJ-G7T as working in py3
  * Fix px888k for python3
  * Add Baofeng BF-M4
  * Add alias for TG-UV2
  * Add Radtel RT-470L fixes
  * Record BF-777S alias of FB-888
  * Fix thd72 tone list
  * Fix right-click in memedit on linux
- fix up spec to standard Python for Factory submission
- disable phone home feature, add chirp-no-phone-home.patch
- simplify icon packaging and package the scalable version
* Fri Apr 21 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- updated to version (snapshot) 20230421
* Tue Apr  4 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- updated to version (snapshot) 20230404
* Sun Apr  2 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- updated to version (snapshot) 20230402
* Tue Mar 28 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- updated to version (snapshot) 20230328
* Sat Mar 25 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- updated to version (snapshot) 20230322
* Mon Mar 13 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- updated to version (snapshot) 20230313
* Sat Mar  4 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- updated to version (snapshot) 20230304
* Fri Feb 24 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- updated to version (snapshot) 20230224
- patch chirp-backport-to-python36.patch to fix compatibility with
  earlier python version (only for Leap 15.4)
* Mon Feb 20 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- updated to version (snapshot) 20230219
- fixed runtime dependencies
* Sun Feb 19 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- updated to version (snapshot) 20230218
- fixed runtime dependencies
* Fri Feb 17 2023 Wojciech Kazubski <wk@ire.pw.edu.pl>
- updated to version (snapshot) 20230217
- builds with python 3 (up to 3.9)
- added icon files extracted from .ico file that was included in
  older Python 2 versions.
* Sat Dec 17 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20221217
* Wed Dec 14 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20221214
* Wed Dec  7 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20221207
* Wed Nov 30 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20221130
* Wed Nov 23 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20221123
* Sun Nov 20 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20221120
* Wed Nov  9 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20221109
* Wed Oct 26 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20221025
* Sat Oct 22 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20221022
* Wed Oct 19 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20221019
* Thu Oct 13 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20221012
* Mon Oct 10 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20221010
* Sun Oct  2 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20221002
* Sat Sep 17 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20220917
* Sun Sep 11 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20220911
* Sat Sep 10 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20220909
* Tue Aug 23 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20220823
* Mon Aug 22 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20220822
* Sun Aug 14 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20220808
* Tue Jul 26 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20220726
* Mon Jul  4 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20220703
* Mon Jun 20 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20220620
* Mon Jun 13 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20220613
* Sun Jun  5 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20220604
* Sat Jun  4 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20220602
* Wed Jun  1 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20220531
* Mon May 16 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20220515
* Fri Apr  8 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20220408
* Sat Apr  2 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20220402
* Tue Mar  8 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20220308
* Sat Feb 19 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20220219
* Fri Feb 11 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20220210
* Wed Feb  2 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20220202
* Tue Jan 18 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20220118
* Sun Jan 16 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20220115
* Wed Jan  5 2022 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20220103
* Wed Dec 22 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20211221
* Thu Dec 16 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20211216
* Mon Dec 13 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20211213
* Tue Dec  7 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20211207
* Thu Nov 18 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20211118
* Tue Nov 16 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20211116
* Fri Nov  5 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20211105
* Sun Oct 17 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20211016
* Thu Sep 30 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20210930
* Thu Sep 23 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20210922
* Sun Sep 19 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20210919
* Mon Aug 30 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20210830
* Sat Aug 21 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20210821
* Sat Aug 14 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20210814
* Sat Jul 24 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20210724
* Thu Jul 15 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20210706
* Mon Jul  5 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20210705
* Sun Jun 20 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20210618
* Mon Jun 14 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20210612
* Fri May 21 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20210520
* Sun May  2 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20210429
* Wed Apr 28 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20210428
* Fri Apr 16 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20210416
* Wed Apr  7 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20210406
* Wed Mar 10 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20210310
* Sun Mar  7 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20210307
* Fri Feb 12 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20210212
* Wed Jan 13 2021 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20210110
* Mon Dec 21 2020 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20201221
* Mon Nov 30 2020 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20201128
* Thu Nov 26 2020 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20201125
* Sun Nov 22 2020 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20201121
* Fri Nov 20 2020 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version 20201120
* Wed Oct 14 2020 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily 20201014
* Sat Oct 10 2020 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily 20201008
* Wed Sep  9 2020 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily 20200909
* Wed Sep  2 2020 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily 20200902
* Thu Aug 27 2020 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily 20200827
* Fri Aug  7 2020 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily 20200807
* Mon Jul 20 2020 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily 20200718
* Mon Jul 13 2020 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily 20200711
* Mon Jun 22 2020 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily 20200622
* Fri Jun  5 2020 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily 20200603
* Thu May 21 2020 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily 20200521
* Sat May 16 2020 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily 20200516
* Thu Apr 30 2020 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily 20200430
* Fri Apr 10 2020 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily 20200409
* Thu Feb 27 2020 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily 20200227
* Thu Feb 13 2020 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily 20200213
* Sat Feb  8 2020 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily 20200207
- fixed build for Tumbleweed and Factory
* Wed Feb  5 2020 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily-20200204
* Fri Jan 10 2020 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily-20200107
* Sat Jan  4 2020 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily-20200104
* Sat Dec 21 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily-20191221
* Sun Dec  8 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily-20191206
* Thu Dec  5 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily-20191205
* Sat Nov 23 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily-20191123
* Tue Nov 19 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily-20191119
* Fri Nov 15 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily-20191110
* Tue Oct 29 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily-20191029
* Fri Oct 25 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily-20191022
* Sat Oct 19 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily-20191018
* Wed Sep 25 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily-20190925
- fix build for Tumbleweed
* Thu Sep  5 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily-20190905
* Thu Aug 29 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily-20190829
* Sat Aug 24 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily-20190824
* Sun Aug 18 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily-20190817
* Fri Aug 16 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily-20190812
* Sat Jul 20 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily-20190718
* Sat Jul 13 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily-20190713
* Fri Jul 12 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily-20190712
* Thu Jul  4 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily-20190703
* Thu Jun 27 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily-20190626
* Sun Jun  2 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily-20190601
* Fri May 24 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily-20190524
* Thu May 16 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily-20190516
* Sat May 11 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily-20190511
* Mon Apr 29 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily-20190429
* Thu Apr 25 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily-20190424
* Thu Apr 18 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily-20190412
* Thu Mar 21 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily-20190321
* Tue Mar  5 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily-20190304
* Fri Feb 22 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily-20190222
* Wed Feb  6 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily-20190206
* Sun Feb  3 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily-20190201
* Tue Jan 22 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily-20190120
* Sun Jan 13 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily-20190112
* Fri Jan  4 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily-20190104
* Sat Dec 15 2018 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily-20181214
* Thu Dec  6 2018 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily-20181205
* Wed Nov 28 2018 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily-20181128
* Thu Oct 18 2018 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily-20181018
* Wed Oct 10 2018 Wojciech Kazubski <wk@ire.pw.edu.pl>
- update to version daily-20181009
* Sat Sep  8 2018 wk@ire.pw.edu.pl
- update to version daily-20180906
* Mon Aug 20 2018 wk@ire.pw.edu.pl
- update to version daily-20180815
* Sat Jul  7 2018 wk@ire.pw.edu.pl
- update to version daily-20180707
* Sat Jun 23 2018 wk@ire.pw.edu.pl
- update to version daily-20180623
* Wed Jun  6 2018 wk@ire.pw.edu.pl
- update to version daily-20180606
* Sun May 20 2018 wk@ire.pw.edu.pl
- update to version daily-20180519
* Sat May 12 2018 wk@ire.pw.edu.pl
- update to version daily-20180510
* Sat Apr 14 2018 wk@ire.pw.edu.pl
- update to version daily-20180412
* Sun Mar 25 2018 wk@ire.pw.edu.pl
- update to version daily-20180325
* Sun Mar 11 2018 wk@ire.pw.edu.pl
- update to version daily-20180309
* Sun Feb 11 2018 wk@ire.pw.edu.pl
- update to version daily-20180210
* Sat Jan 20 2018 wk@ire.pw.edu.pl
- update to version daily-20180115
* Thu Jan  4 2018 wk@ire.pw.edu.pl
- update to version daily-20180104
* Fri Dec 29 2017 wk@ire.pw.edu.pl
- update to version daily-20171229
* Mon Dec  4 2017 wk@ire.pw.edu.pl
- update to version daily-20171204
* Thu Nov 23 2017 wk@ire.pw.edu.pl
- update to version daily-20171120
* Fri Oct 13 2017 wk@ire.pw.edu.pl
- update to version daily-20171013
* Tue Oct 10 2017 wk@ire.pw.edu.pl
- update to version daily-20171008
* Sun Jul 16 2017 wk@ire.pw.edu.pl
- update to version daily-20170714
* Thu Jun 15 2017 wk@ire.pw.edu.pl
- update to version daily-20170608
* Sat May  6 2017 frede@b1-systems.de
- update to version daily-20170501
* Fri Mar 31 2017 wk@ire.pw.edu.pl
- update to version daily-20170330
* Sat Mar 25 2017 wk@ire.pw.edu.pl
- update to version daily-20170324
* Wed Dec 28 2016 wk@ire.pw.edu.pl
- update to version daily-20161220
* Sun Oct 23 2016 wk@ire.pw.edu.pl
- update to version daily-20161018
* Thu Sep  1 2016 wk@ire.pw.edu.pl
- update to version daily-20160830
* Mon Jul 25 2016 wk@ire.pw.edu.pl
- update to version daily-20160717
* Sun Jun 19 2016 wk@ire.pw.edu.pl
-  update to version daily-20160615
* Sat Jun  4 2016 wk@ire.pw.edu.pl
- update to version daily-20160604
* Sat May 21 2016 wk@ire.pw.edu.pl
- update to version daily-20160517
* Fri Mar 11 2016 frede@b1-systems.de
- update to version daily-20160309
* Sun Jan 31 2016 frede@b1-systems.de
- update to version daily-20160128
* Fri Jan 22 2016 frede@b1-systems.de
- update to version daily-20160116
* Tue Oct 21 2014 dl8fcl@darc.de
- updated to version 0.4.1
* Mon Apr 21 2014 dl8fcl@darc.de
- spec file updated for openSUSE
- GenericName in desktop file changed
* Sat Apr  5 2014 wk@ire.pw.edu.pl - 0.4.0-2
- updated to version 0.4.0
* Mon Feb 17 2014 wk@ire.pw.edu.pl - 0.3.1-1
- version 0.3.1
- initial specfile
